<?php
// $Id: custom.inc,v 1.9.2.3 2010/01/29 20:18:25 merlinofchaos Exp $

/**
 * @file
 * Custom content type.
 *
 * This content type is nothing more than a title and a body that is entered
 * by the user and run through standard filters. The information is stored
 * right in the config, so each custom content is unique.
 */

/**
 * Plugins are described by creating a $plugin array which will be used
 * by the system that includes this file.
 */
$plugin = array(
  'key' => 'link',
  'single' => TRUE,
  'title' => t('New link'),
  'icon' => 'icon_link.png',
  'description' => t('Create a link.'),
  // Make this a top level category so it appears higher in UIs that support
  // that.
  'top level' => TRUE,
  'category' => t('Custom'),
  'defaults' => array(
    'admin_title' => '',
    'title' => '',
    'link_text' => '',
    'link_url' => '',
    'link_css' => '',
  ),
  // render callback is automatically deduced:
  'render callback' => 'ctoolscustomplugins_link_content_type_render',
  'js' => array('misc/autocomplete.js', 'misc/textarea.js', 'misc/collapse.js'),
  'all contexts' => TRUE,
);

/**
 * Output function for the 'custom' content type. Outputs a custom
 * based on the module and delta supplied in the configuration.
 */
function ctoolscustomplugins_link_content_type_render($subtype, $conf, $args, $contexts) {
  static $delta = 0;

  $block          = new stdClass();
  $block->subtype = ++$delta;
  $block->title   = filter_xss_admin($conf['title']);
  $block->content = '';
  $block->content .= l($conf['link_text'], $conf['link_url'], $options = array('attributes' => array('class' => $conf['link_css'])));

  return $block;
}

/**
 * Callback to provide administrative info. In this case we'll render the
 * content as long as it's not PHP, which is too risky to render here.
 */
function ctoolscustomplugins_link_content_type_admin_info($subtype, $conf) {
  $block = new stdClass();
  $block->title = filter_xss_admin($conf['title']);  
  $block->content .= l($conf['link_text'], $conf['link_url'], $options = array('attributes' => array('class' => $conf['link_css'])));
  
  return $block;
}

/**
 * Callback to provide the administrative title of the custom content.
 */
function ctoolscustomplugins_link_content_type_admin_title($subtype, $conf) {
  $output = t('Custom');
  $title = !empty($conf['admin_title']) ? $conf['admin_title'] : $conf['title'];
  if ($title) {
    $output = t('Custom: @title', array('@title' => $title));
  }
  return $output;
}

/**
 * Returns an edit form for the custom type.
 */
function ctoolscustomplugins_link_content_type_edit_form(&$form, &$form_state) {
  $conf = $form_state['conf'];
  $form['admin_title'] = array(
    '#type' => 'textfield',
    '#default_value' => isset($conf['admin_title']) ? $conf['admin_title'] : '',
    '#title' => t('Administrative title'),
    '#description' => t('This title will be used administratively to identify this pane. If blank, the regular title will be used.'),
  );

  $form['title'] = array(
    '#type' => 'textfield',
    '#default_value' => $conf['title'],
    '#title' => t('Title'),
  );
  
  $form['link'] = array(
    '#type' => 'fieldset',
    '#title' => t('Link'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  
  $form['link']['link_text'] = array(
    '#type' => 'textfield',
    '#default_value' => $conf['link_text'],
    '#title' => t('Link Text'),
  );
  
  $form['link']['link_url'] = array(
    '#type' => 'textfield',
    '#default_value' => $conf['link_url'],
    '#title' => t('Link URL'),
    '#description' => t("If you use http:// before the URI, the link will open in a new window"),
  );
  
  $form['link']['link_css'] = array(
    '#type' => 'textfield',
    '#default_value' => $conf['link_css'],
    '#title' => t('Link CSS Class'),
    '#description' => t("Add a CSS class to control how this link looks"),
  );

  return $form;
}

/**
 * The submit form stores the data in $conf.
 */
function ctoolscustomplugins_link_content_type_edit_form_submit(&$form, &$form_state) {
  foreach (array_keys($form_state['plugin']['defaults']) as $key) {
    if (isset($form_state['values'][$key])) {
      $form_state['conf'][$key] = $form_state['values'][$key];
    }
  }  
}
